.. _physics-docs:

==============
Physics Module
==============

.. automodule:: sympy.physics

Contents
========

.. toctree::
    :maxdepth: 3

    hydrogen.rst
    matrices.rst
    paulialgebra.rst
    qho_1d.rst
    sho.rst
    secondquant.rst
    wigner.rst
    units/index.rst
    hep/index.rst
    vector/index.rst
    mechanics/index.rst
    quantum/index.rst
    optics/index.rst
    units/index.rst
    continuum_mechanics/index.rst
